# Gets the default gateway (Windows only)

## pip install getdefgateway

### Tested against Python 3.9.15 / Windows 10 / Anaconda 


```python

from getdefgateway import get_default_gateway
get_default_gateway()

'117.11.21.12'

```